@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from voxypy.models.models import Voxel
+from voxypy.models import Voxel
 
 
 class TestVoxel(TestCase):
